Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1522)

Unified Diff: content/renderer/render_process_impl.cc

Issue 2581353002: Use the Windows MDM API to check if the machine is being managed. (Closed)
Patch Set: rebased Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/render_process_impl.cc
diff --git a/content/renderer/render_process_impl.cc b/content/renderer/render_process_impl.cc
index 39819457dbb0bf474d116f0d29d6445a632643c5..ede64934c0f65656d0c59ba4cf209c2ee94dfb55 100644
--- a/content/renderer/render_process_impl.cc
+++ b/content/renderer/render_process_impl.cc
@@ -139,12 +139,12 @@ RenderProcessImpl::RenderProcessImpl(
std::move(worker_pool_index_for_traits_callback)),
enabled_bindings_(0) {
#if defined(OS_WIN)
// Record whether the machine is domain joined in a crash key. This will be
// used to better identify whether crashes are from enterprise users.
// Note that this is done very early on so that crashes have the highest
// chance of getting tagged.
- base::debug::SetCrashKeyValue("enrolled-to-domain",
- base::win::IsEnrolledToDomain() ? "yes" : "no");
+ base::debug::SetCrashKeyValue(
+ "is-enterprise-managed", base::win::IsEnterpriseManaged() ? "yes" : "no");
// HACK: See http://b/issue?id=1024307 for rationale.
if (GetModuleHandle(L"LPK.DLL") == NULL) {
@@ -139,12 +139,12 @@ RenderProcessImpl::RenderProcessImpl(
enabled_bindings_(0) {
#if defined(OS_WIN)
- // Record whether the machine is domain joined in a crash key. This will be
- // used to better identify whether crashes are from enterprise users.
+ // Record whether the machine is enterprise managed in a crash key. This
+ // will be used to better identify whether crashes are from enterprise users.
// Note that this is done very early on so that crashes have the highest
// chance of getting tagged.

Powered by Google App Engine
This is Rietveld 408576698